sphinx-swagger-doc
==================

|Beerpay| |Beerpay| |GitHub stars|

    Sphinx extension for documenting Swagger 2.0 APIs

Please ★ this repo if you found it useful ★ ★ ★

Features
--------

-  Swagger 2.0 spec
-  Generate sphinx doc

Installation
------------

.. code:: sh

    pip install sphinx-swagger-doc

Dependencies
------------

-  `Python <https://www.python.org>`__
-  `Sphinx <http://www.sphinx-doc.org>`__

Usage
-----

`Contribute <https://github.com/jamrizzi/sphinx-swagger-doc/blob/master/CONTRIBUTING.md>`__
usage docs

Support
-------

Submit an
`issue <https://github.com/jamrizzi/sphinx-swagger-doc/issues/new>`__

Screenshots
-----------

`Contribute <https://github.com/jamrizzi/sphinx-swagger-doc/blob/master/CONTRIBUTING.md>`__
a screenshot

Contributing
------------

Review the `guidelines for
contributing <https://github.com/jamrizzi/sphinx-swagger-doc/blob/master/CONTRIBUTING.md>`__

License
-------

`MIT
License <https://github.com/jamrizzi/sphinx-swagger-doc/blob/master/LICENSE>`__

`Jam Risser <https://jamrizzi.com>`__ © 2018

Changelog
---------

Review the
`changelog <https://github.com/jamrizzi/sphinx-swagger-doc/blob/master/CHANGELOG.md>`__

Credits
-------

-  `Jam Risser <https://jamrizzi.com>`__ - Author

Support on Beerpay (actually, I drink coffee)
---------------------------------------------

A ridiculous amount of coffee :coffee: :coffee: :coffee: was consumed in
the process of building this project.

`Add some fuel <https://beerpay.io/jamrizzi/sphinx-swagger-doc>`__ if
you’d like to keep me going!

|Beerpay| |Beerpay|

.. |Beerpay| image:: https://beerpay.io/jamrizzi/sphinx-swagger-doc/badge.svg?style=beer-square
   :target: https://beerpay.io/jamrizzi/sphinx-swagger-doc
.. |Beerpay| image:: https://beerpay.io/jamrizzi/sphinx-swagger-doc/make-wish.svg?style=flat-square
   :target: https://beerpay.io/jamrizzi/sphinx-swagger-doc?focus=wish
.. |GitHub stars| image:: https://img.shields.io/github/stars/jamrizzi/sphinx-swagger-doc.svg?style=social&label=Stars
   :target: https://github.com/jamrizzi/sphinx-swagger-doc
.. |Beerpay| image:: https://beerpay.io/jamrizzi/sphinx-swagger-doc/badge.svg?style=beer-square
   :target: https://beerpay.io/jamrizzi/sphinx-swagger-doc
.. |Beerpay| image:: https://beerpay.io/jamrizzi/sphinx-swagger-doc/make-wish.svg?style=flat-square
   :target: https://beerpay.io/jamrizzi/sphinx-swagger-doc?focus=wish
